Where to Go from Here

# XMLRésuméLibrary: User Guide

Writing your first XML Résumé | Exploring the Features of XML Résumé Library | About this chapter

## Where to Go from Here

### Documentation

More detailed information about creating and building résumés is available in other sections of this user guide.

For more information about the XML Résumé Library, see the HTML documentation included in the `doc/` directory.

### Support

For questions about the package and the DTD, there is a mailing list and a support forum web site.

The online support forum is located at http://sourceforge.net/tracker/?group_id=29512&atid=396336.

To join the mailing list, either visit http://lists.sourceforge.net/lists/listinfo/xmlresume-devel or send a message with `subscribe `[youraddress@yourdomain.tld]`` in the body to `<xmlresume-devel-request@lists.sourceforge.net>`.

Writing your first XML Résumé | Exploring the Features of XML Résumé Library | About this chapter